@@ -3,6 +3,7 @@ mod core;
 use pyo3::prelude::*;
 use crate::core::agent::Agent;
 use crate::core::manager::AgentManager;
+use crate::core::plugins::metric_feature::AgentMetric;
 
 
 /// A Python module implemented in Rust.
@@ -12,5 +13,6 @@ fn rakun_python(_py: Python, m: &PyModule) -> PyResult<()> {
     // m.add_function(wrap_pyfunction!(create_agent, m)?)?;
     m.add_class::<Agent>()?;
     m.add_class::<AgentManager>()?;
+    m.add_class::<AgentMetric>()?;
     Ok(())
 }
\ No newline at end of file
